@@ -1,4 +1,4 @@
-"""Test cases for SuperFences."""
+"""Test cases for Tabbed."""
 from .. import util
 from pymdownx.slugs import slugify
 
@@ -231,7 +231,7 @@ class TestLegacyTab(util.MdCase):
             True
         )
 
-    def test_tabbed_select_mulitiple(self):
+    def test_tabbed_select_multiple(self):
         """Test selecting multiple tabs."""
 
         self.check_markdown(
@@ -508,6 +508,27 @@ class TestLegacyTab(util.MdCase):
             True
         )
 
+    def test_indented_code(self):
+        """Test indented code."""
+
+        md = """
+        === "Tab 1"
+
+                code
+        """
+
+        self.check_markdown(
+            md,
+            '''
+            <div class="tabbed-set" data-tabs="1:1"><input checked="checked" id="__tabbed_1_1" name="__tabbed_1" type="radio" /><label for="__tabbed_1_1">Tab 1</label><div class="tabbed-content">
+            <pre><code>code
+            </code></pre>
+            </div>
+            </div>
+            ''',  # noqa: E501
+            True
+        )
+
 
 class TestLegacyTabSlugs(util.MdCase):
     """Test legacy tab slug cases."""
@@ -577,3 +598,92 @@ class TestLegacyTabSlugsSep(util.MdCase):
             ''',  # noqa: E501
             True
         )
+
+
+class TestTabSlugsCombineHeader(util.MdCase):
+    """Combine header slug with content tab."""
+
+    extension = ['pymdownx.tabbed', 'toc', 'pymdownx.details']
+    extension_configs = {
+        'pymdownx.tabbed': {
+            'slugify': slugify(case='lower'),
+            'combine_header_slug': True
+        }
+    }
+
+    def test_combine_header_slug(self):
+        """Test that slugs are a combination of the header slug and the tab title."""
+
+        md = R"""
+        ### Here is some text
+
+        === "First Tab"
+            content
+
+        ### Another header
+
+        ??? "title"
+            === "Second Tab"
+                content
+        """
+
+        self.check_markdown(
+            md,
+            '''
+            <h3 id="here-is-some-text">Here is some text</h3>
+            <div class="tabbed-set" data-tabs="1:1"><input checked="checked" id="here-is-some-text-first-tab" name="__tabbed_1" type="radio" /><label for="here-is-some-text-first-tab">First Tab</label><div class="tabbed-content">
+            <p>content</p>
+            </div>
+            </div>
+            <h3 id="another-header">Another header</h3>
+            <details>
+            <summary>title</summary>
+            <div class="tabbed-set" data-tabs="2:1"><input checked="checked" id="another-header-second-tab" name="__tabbed_2" type="radio" /><label for="another-header-second-tab">Second Tab</label><div class="tabbed-content">
+            <p>content</p>
+            </div>
+            </div>
+            </details>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_no_header(self):
+        """Test when there is no header."""
+
+        md = R"""
+        === "A Tab"
+            content
+        """
+
+        self.check_markdown(
+            md,
+            '''
+            <div class="tabbed-set" data-tabs="1:1"><input checked="checked" id="a-tab" name="__tabbed_1" type="radio" /><label for="a-tab">A Tab</label><div class="tabbed-content">
+            <p>content</p>
+            </div>
+            </div>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_header_after(self):
+        """Test when header comes after."""
+
+        md = R"""
+        === "A Tab"
+            content
+
+        # Header
+        """
+
+        self.check_markdown(
+            md,
+            '''
+            <div class="tabbed-set" data-tabs="1:1"><input checked="checked" id="a-tab" name="__tabbed_1" type="radio" /><label for="a-tab">A Tab</label><div class="tabbed-content">
+            <p>content</p>
+            </div>
+            </div>
+            <h1 id="header">Header</h1>
+            ''',  # noqa: E501
+            True
+        )
